Introduction

cole Library Reference Manual
Prev |  | Next

# Chapter 1. Introduction

# What is cole?

cole is a free C OLE library.

cole is distributed under the terms of the GNU General Public License (GPL) to give an impulse to the Free Software. cole distribution license is compatible with the Open Source definition.

Using cole, you can access Microsoft' Structured Storage files. The most popular Microsoft's programs generate Structured Storage files, incluiding the Microsoft' suite for offices. StarDivision' suite (StarOffice) generate Structured Storage files too. FlashPix file format is Structured Storage too.

What is a Structured Storage file? Inside a Structured Storage file there is a filesystem, with directories and files, which Microsoft calls containers and streams. Using cole you can travel through such filesystem and access the files.

cole doesn't know about internal structure of a stream, it only reads the raw data. You can use the Microsoft's documentation available at http://msdn.microsoft.com or the information available at http://www.wotsit.org to know the binary file format of the streams. If you know anything in the side of StarDivision email me. FlashPix file format is well documented.

cole was developed using the information available at http://wwwwbs.cs.tu-berlin.de/~schwartz/pmh/guide.html and the OLE::Storage Perl module from the same site, and no information from any other source (incluiding Microsoft) has been used.

Prev | Home | Next
cole Library Reference Manual |  | Features